Documentation
¶
Index ¶
- Variables
- func RegisterDBServer(s grpc.ServiceRegistrar, srv DBServer)
- func RegisterETHBACKENDServer(s grpc.ServiceRegistrar, srv ETHBACKENDServer)
- func RegisterKVServer(s grpc.ServiceRegistrar, srv KVServer)
- type AddReply
- type BucketSizeReply
- type BucketSizeRequest
- func (*BucketSizeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *BucketSizeRequest) GetBucketName() string
- func (*BucketSizeRequest) ProtoMessage()
- func (x *BucketSizeRequest) ProtoReflect() protoreflect.Message
- func (x *BucketSizeRequest) Reset()
- func (x *BucketSizeRequest) String() string
- type Cursor
- func (*Cursor) Descriptor() ([]byte, []int)deprecated
- func (x *Cursor) GetBucketName() string
- func (x *Cursor) GetCursor() uint32
- func (x *Cursor) GetK() []byte
- func (x *Cursor) GetOp() Op
- func (x *Cursor) GetV() []byte
- func (*Cursor) ProtoMessage()
- func (x *Cursor) ProtoReflect() protoreflect.Message
- func (x *Cursor) Reset()
- func (x *Cursor) String() string
- type DBClient
- type DBServer
- type ETHBACKENDClient
- type ETHBACKENDServer
- type ETHBACKEND_SubscribeClient
- type ETHBACKEND_SubscribeServer
- type EtherbaseReply
- type EtherbaseRequest
- type KVClient
- type KVServer
- type KV_TxClient
- type KV_TxServer
- type NetVersionReply
- type NetVersionRequest
- type Op
- type Pair
- type SizeReply
- type SizeRequest
- type SubscribeReply
- func (*SubscribeReply) Descriptor() ([]byte, []int)deprecated
- func (x *SubscribeReply) GetData() []byte
- func (x *SubscribeReply) GetType() uint64
- func (*SubscribeReply) ProtoMessage()
- func (x *SubscribeReply) ProtoReflect() protoreflect.Message
- func (x *SubscribeReply) Reset()
- func (x *SubscribeReply) String() string
- type SubscribeRequest
- type TxRequest
- type UnimplementedDBServer
- type UnimplementedETHBACKENDServer
- func (UnimplementedETHBACKENDServer) Add(context.Context, *TxRequest) (*AddReply, error)
- func (UnimplementedETHBACKENDServer) Etherbase(context.Context, *EtherbaseRequest) (*EtherbaseReply, error)
- func (UnimplementedETHBACKENDServer) NetVersion(context.Context, *NetVersionRequest) (*NetVersionReply, error)
- func (UnimplementedETHBACKENDServer) Subscribe(*SubscribeRequest, ETHBACKEND_SubscribeServer) error
- type UnimplementedKVServer
- type UnsafeDBServer
- type UnsafeETHBACKENDServer
- type UnsafeKVServer
Constants ¶
This section is empty.
Variables ¶
var ( Op_name = map[int32]string{ 0: "FIRST", 1: "FIRST_DUP", 2: "SEEK", 3: "SEEK_BOTH", 4: "CURRENT", 6: "LAST", 7: "LAST_DUP", 8: "NEXT", 9: "NEXT_DUP", 11: "NEXT_NO_DUP", 12: "PREV", 13: "PREV_DUP", 14: "PREV_NO_DUP", 15: "SEEK_EXACT", 16: "SEEK_BOTH_EXACT", 30: "OPEN", 31: "CLOSE", } Op_value = map[string]int32{ "FIRST": 0, "FIRST_DUP": 1, "SEEK": 2, "SEEK_BOTH": 3, "CURRENT": 4, "LAST": 6, "LAST_DUP": 7, "NEXT": 8, "NEXT_DUP": 9, "NEXT_NO_DUP": 11, "PREV": 12, "PREV_DUP": 13, "PREV_NO_DUP": 14, "SEEK_EXACT": 15, "SEEK_BOTH_EXACT": 16, "OPEN": 30, "CLOSE": 31, } )
Enum value maps for Op.
var File_remote_db_proto protoreflect.FileDescriptor
var File_remote_ethbackend_proto protoreflect.FileDescriptor
var File_remote_kv_proto protoreflect.FileDescriptor
Functions ¶
func RegisterDBServer ¶
func RegisterDBServer(s grpc.ServiceRegistrar, srv DBServer)
func RegisterETHBACKENDServer ¶
func RegisterETHBACKENDServer(s grpc.ServiceRegistrar, srv ETHBACKENDServer)
func RegisterKVServer ¶
func RegisterKVServer(s grpc.ServiceRegistrar, srv KVServer)
Types ¶
type AddReply ¶
type AddReply struct {
Hash []byte `protobuf:"bytes,1,opt,name=hash,proto3" json:"hash,omitempty"`
// contains filtered or unexported fields
}
func (*AddReply) Descriptor
deprecated
func (*AddReply) ProtoMessage ¶
func (*AddReply) ProtoMessage()
func (*AddReply) ProtoReflect ¶
func (x *AddReply) ProtoReflect() protoreflect.Message
type BucketSizeReply ¶
type BucketSizeReply struct {
Size uint64 `protobuf:"varint,1,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
func (*BucketSizeReply) Descriptor
deprecated
func (*BucketSizeReply) Descriptor() ([]byte, []int)
Deprecated: Use BucketSizeReply.ProtoReflect.Descriptor instead.
func (*BucketSizeReply) GetSize ¶
func (x *BucketSizeReply) GetSize() uint64
func (*BucketSizeReply) ProtoMessage ¶
func (*BucketSizeReply) ProtoMessage()
func (*BucketSizeReply) ProtoReflect ¶
func (x *BucketSizeReply) ProtoReflect() protoreflect.Message
func (*BucketSizeReply) Reset ¶
func (x *BucketSizeReply) Reset()
func (*BucketSizeReply) String ¶
func (x *BucketSizeReply) String() string
type BucketSizeRequest ¶
type BucketSizeRequest struct {
BucketName string `protobuf:"bytes,1,opt,name=bucketName,proto3" json:"bucketName,omitempty"`
// contains filtered or unexported fields
}
func (*BucketSizeRequest) Descriptor
deprecated
func (*BucketSizeRequest) Descriptor() ([]byte, []int)
Deprecated: Use BucketSizeRequest.ProtoReflect.Descriptor instead.
func (*BucketSizeRequest) GetBucketName ¶
func (x *BucketSizeRequest) GetBucketName() string
func (*BucketSizeRequest) ProtoMessage ¶
func (*BucketSizeRequest) ProtoMessage()
func (*BucketSizeRequest) ProtoReflect ¶
func (x *BucketSizeRequest) ProtoReflect() protoreflect.Message
func (*BucketSizeRequest) Reset ¶
func (x *BucketSizeRequest) Reset()
func (*BucketSizeRequest) String ¶
func (x *BucketSizeRequest) String() string
type Cursor ¶
type Cursor struct {
Op Op `protobuf:"varint,1,opt,name=op,proto3,enum=remote.Op" json:"op,omitempty"`
BucketName string `protobuf:"bytes,2,opt,name=bucketName,proto3" json:"bucketName,omitempty"`
Cursor uint32 `protobuf:"varint,3,opt,name=cursor,proto3" json:"cursor,omitempty"`
K []byte `protobuf:"bytes,4,opt,name=k,proto3" json:"k,omitempty"`
V []byte `protobuf:"bytes,5,opt,name=v,proto3" json:"v,omitempty"`
// contains filtered or unexported fields
}
func (*Cursor) Descriptor
deprecated
func (*Cursor) GetBucketName ¶
func (*Cursor) ProtoMessage ¶
func (*Cursor) ProtoMessage()
func (*Cursor) ProtoReflect ¶
func (x *Cursor) ProtoReflect() protoreflect.Message
type DBClient ¶
type DBClient interface {
Size(ctx context.Context, in *SizeRequest, opts ...grpc.CallOption) (*SizeReply, error)
BucketSize(ctx context.Context, in *BucketSizeRequest, opts ...grpc.CallOption) (*BucketSizeReply, error)
}
DBClient is the client API for DB service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewDBClient ¶
func NewDBClient(cc grpc.ClientConnInterface) DBClient
type DBServer ¶
type DBServer interface {
Size(context.Context, *SizeRequest) (*SizeReply, error)
BucketSize(context.Context, *BucketSizeRequest) (*BucketSizeReply, error)
// contains filtered or unexported methods
}
DBServer is the server API for DB service. All implementations must embed UnimplementedDBServer for forward compatibility
type ETHBACKENDClient ¶
type ETHBACKENDClient interface {
Add(ctx context.Context, in *TxRequest, opts ...grpc.CallOption) (*AddReply, error)
Etherbase(ctx context.Context, in *EtherbaseRequest, opts ...grpc.CallOption) (*EtherbaseReply, error)
NetVersion(ctx context.Context, in *NetVersionRequest, opts ...grpc.CallOption) (*NetVersionReply, error)
Subscribe(ctx context.Context, in *SubscribeRequest, opts ...grpc.CallOption) (ETHBACKEND_SubscribeClient, error)
}
ETHBACKENDClient is the client API for ETHBACKEND service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewETHBACKENDClient ¶
func NewETHBACKENDClient(cc grpc.ClientConnInterface) ETHBACKENDClient
type ETHBACKENDServer ¶
type ETHBACKENDServer interface {
Add(context.Context, *TxRequest) (*AddReply, error)
Etherbase(context.Context, *EtherbaseRequest) (*EtherbaseReply, error)
NetVersion(context.Context, *NetVersionRequest) (*NetVersionReply, error)
Subscribe(*SubscribeRequest, ETHBACKEND_SubscribeServer) error
// contains filtered or unexported methods
}
ETHBACKENDServer is the server API for ETHBACKEND service. All implementations must embed UnimplementedETHBACKENDServer for forward compatibility
type ETHBACKEND_SubscribeClient ¶
type ETHBACKEND_SubscribeClient interface {
Recv() (*SubscribeReply, error)
grpc.ClientStream
}
type ETHBACKEND_SubscribeServer ¶
type ETHBACKEND_SubscribeServer interface {
Send(*SubscribeReply) error
grpc.ServerStream
}
type EtherbaseReply ¶
type EtherbaseReply struct {
Hash []byte `protobuf:"bytes,1,opt,name=hash,proto3" json:"hash,omitempty"`
// contains filtered or unexported fields
}
func (*EtherbaseReply) Descriptor
deprecated
func (*EtherbaseReply) Descriptor() ([]byte, []int)
Deprecated: Use EtherbaseReply.ProtoReflect.Descriptor instead.
func (*EtherbaseReply) GetHash ¶
func (x *EtherbaseReply) GetHash() []byte
func (*EtherbaseReply) ProtoMessage ¶
func (*EtherbaseReply) ProtoMessage()
func (*EtherbaseReply) ProtoReflect ¶
func (x *EtherbaseReply) ProtoReflect() protoreflect.Message
func (*EtherbaseReply) Reset ¶
func (x *EtherbaseReply) Reset()
func (*EtherbaseReply) String ¶
func (x *EtherbaseReply) String() string
type EtherbaseRequest ¶
type EtherbaseRequest struct {
// contains filtered or unexported fields
}
func (*EtherbaseRequest) Descriptor
deprecated
func (*EtherbaseRequest) Descriptor() ([]byte, []int)
Deprecated: Use EtherbaseRequest.ProtoReflect.Descriptor instead.
func (*EtherbaseRequest) ProtoMessage ¶
func (*EtherbaseRequest) ProtoMessage()
func (*EtherbaseRequest) ProtoReflect ¶
func (x *EtherbaseRequest) ProtoReflect() protoreflect.Message
func (*EtherbaseRequest) Reset ¶
func (x *EtherbaseRequest) Reset()
func (*EtherbaseRequest) String ¶
func (x *EtherbaseRequest) String() string
type KVClient ¶
type KVClient interface {
Tx(ctx context.Context, opts ...grpc.CallOption) (KV_TxClient, error)
}
KVClient is the client API for KV service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewKVClient ¶
func NewKVClient(cc grpc.ClientConnInterface) KVClient
type KVServer ¶
type KVServer interface {
Tx(KV_TxServer) error
// contains filtered or unexported methods
}
KVServer is the server API for KV service. All implementations must embed UnimplementedKVServer for forward compatibility
type KV_TxClient ¶
type KV_TxServer ¶
type NetVersionReply ¶
type NetVersionReply struct {
Id uint64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
// contains filtered or unexported fields
}
func (*NetVersionReply) Descriptor
deprecated
func (*NetVersionReply) Descriptor() ([]byte, []int)
Deprecated: Use NetVersionReply.ProtoReflect.Descriptor instead.
func (*NetVersionReply) GetId ¶
func (x *NetVersionReply) GetId() uint64
func (*NetVersionReply) ProtoMessage ¶
func (*NetVersionReply) ProtoMessage()
func (*NetVersionReply) ProtoReflect ¶
func (x *NetVersionReply) ProtoReflect() protoreflect.Message
func (*NetVersionReply) Reset ¶
func (x *NetVersionReply) Reset()
func (*NetVersionReply) String ¶
func (x *NetVersionReply) String() string
type NetVersionRequest ¶
type NetVersionRequest struct {
// contains filtered or unexported fields
}
func (*NetVersionRequest) Descriptor
deprecated
func (*NetVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use NetVersionRequest.ProtoReflect.Descriptor instead.
func (*NetVersionRequest) ProtoMessage ¶
func (*NetVersionRequest) ProtoMessage()
func (*NetVersionRequest) ProtoReflect ¶
func (x *NetVersionRequest) ProtoReflect() protoreflect.Message
func (*NetVersionRequest) Reset ¶
func (x *NetVersionRequest) Reset()
func (*NetVersionRequest) String ¶
func (x *NetVersionRequest) String() string
type Op ¶
type Op int32
const ( Op_FIRST Op = 0 Op_FIRST_DUP Op = 1 Op_SEEK Op = 2 Op_SEEK_BOTH Op = 3 Op_CURRENT Op = 4 Op_LAST Op = 6 Op_LAST_DUP Op = 7 Op_NEXT Op = 8 Op_NEXT_DUP Op = 9 Op_NEXT_NO_DUP Op = 11 Op_PREV Op = 12 Op_PREV_DUP Op = 13 Op_PREV_NO_DUP Op = 14 Op_SEEK_EXACT Op = 15 Op_SEEK_BOTH_EXACT Op = 16 Op_OPEN Op = 30 Op_CLOSE Op = 31 )
func (Op) Descriptor ¶
func (Op) Descriptor() protoreflect.EnumDescriptor
func (Op) EnumDescriptor
deprecated
func (Op) Number ¶
func (x Op) Number() protoreflect.EnumNumber
func (Op) Type ¶
func (Op) Type() protoreflect.EnumType
type Pair ¶
type Pair struct {
K []byte `protobuf:"bytes,1,opt,name=k,proto3" json:"k,omitempty"`
V []byte `protobuf:"bytes,2,opt,name=v,proto3" json:"v,omitempty"`
CursorID uint32 `protobuf:"varint,3,opt,name=cursorID,proto3" json:"cursorID,omitempty"`
// contains filtered or unexported fields
}
func (*Pair) Descriptor
deprecated
func (*Pair) GetCursorID ¶
func (*Pair) ProtoMessage ¶
func (*Pair) ProtoMessage()
func (*Pair) ProtoReflect ¶
func (x *Pair) ProtoReflect() protoreflect.Message
type SizeReply ¶
type SizeReply struct {
Size uint64 `protobuf:"varint,1,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
func (*SizeReply) Descriptor
deprecated
func (*SizeReply) ProtoMessage ¶
func (*SizeReply) ProtoMessage()
func (*SizeReply) ProtoReflect ¶
func (x *SizeReply) ProtoReflect() protoreflect.Message
type SizeRequest ¶
type SizeRequest struct {
// contains filtered or unexported fields
}
func (*SizeRequest) Descriptor
deprecated
func (*SizeRequest) Descriptor() ([]byte, []int)
Deprecated: Use SizeRequest.ProtoReflect.Descriptor instead.
func (*SizeRequest) ProtoMessage ¶
func (*SizeRequest) ProtoMessage()
func (*SizeRequest) ProtoReflect ¶
func (x *SizeRequest) ProtoReflect() protoreflect.Message
func (*SizeRequest) Reset ¶
func (x *SizeRequest) Reset()
func (*SizeRequest) String ¶
func (x *SizeRequest) String() string
type SubscribeReply ¶
type SubscribeReply struct {
Type uint64 `protobuf:"varint,1,opt,name=type,proto3" json:"type,omitempty"` // type (only header at that moment)
Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"` // serialized data
// contains filtered or unexported fields
}
func (*SubscribeReply) Descriptor
deprecated
func (*SubscribeReply) Descriptor() ([]byte, []int)
Deprecated: Use SubscribeReply.ProtoReflect.Descriptor instead.
func (*SubscribeReply) GetData ¶
func (x *SubscribeReply) GetData() []byte
func (*SubscribeReply) GetType ¶
func (x *SubscribeReply) GetType() uint64
func (*SubscribeReply) ProtoMessage ¶
func (*SubscribeReply) ProtoMessage()
func (*SubscribeReply) ProtoReflect ¶
func (x *SubscribeReply) ProtoReflect() protoreflect.Message
func (*SubscribeReply) Reset ¶
func (x *SubscribeReply) Reset()
func (*SubscribeReply) String ¶
func (x *SubscribeReply) String() string
type SubscribeRequest ¶
type SubscribeRequest struct {
// contains filtered or unexported fields
}
func (*SubscribeRequest) Descriptor
deprecated
func (*SubscribeRequest) Descriptor() ([]byte, []int)
Deprecated: Use SubscribeRequest.ProtoReflect.Descriptor instead.
func (*SubscribeRequest) ProtoMessage ¶
func (*SubscribeRequest) ProtoMessage()
func (*SubscribeRequest) ProtoReflect ¶
func (x *SubscribeRequest) ProtoReflect() protoreflect.Message
func (*SubscribeRequest) Reset ¶
func (x *SubscribeRequest) Reset()
func (*SubscribeRequest) String ¶
func (x *SubscribeRequest) String() string
type TxRequest ¶
type TxRequest struct {
Signedtx []byte `protobuf:"bytes,1,opt,name=signedtx,proto3" json:"signedtx,omitempty"`
// contains filtered or unexported fields
}
func (*TxRequest) Descriptor
deprecated
func (*TxRequest) GetSignedtx ¶
func (*TxRequest) ProtoMessage ¶
func (*TxRequest) ProtoMessage()
func (*TxRequest) ProtoReflect ¶
func (x *TxRequest) ProtoReflect() protoreflect.Message
type UnimplementedDBServer ¶
type UnimplementedDBServer struct {
}
UnimplementedDBServer must be embedded to have forward compatible implementations.
func (UnimplementedDBServer) BucketSize ¶
func (UnimplementedDBServer) BucketSize(context.Context, *BucketSizeRequest) (*BucketSizeReply, error)
func (UnimplementedDBServer) Size ¶
func (UnimplementedDBServer) Size(context.Context, *SizeRequest) (*SizeReply, error)
type UnimplementedETHBACKENDServer ¶
type UnimplementedETHBACKENDServer struct {
}
UnimplementedETHBACKENDServer must be embedded to have forward compatible implementations.
func (UnimplementedETHBACKENDServer) Etherbase ¶
func (UnimplementedETHBACKENDServer) Etherbase(context.Context, *EtherbaseRequest) (*EtherbaseReply, error)
func (UnimplementedETHBACKENDServer) NetVersion ¶
func (UnimplementedETHBACKENDServer) NetVersion(context.Context, *NetVersionRequest) (*NetVersionReply, error)
func (UnimplementedETHBACKENDServer) Subscribe ¶
func (UnimplementedETHBACKENDServer) Subscribe(*SubscribeRequest, ETHBACKEND_SubscribeServer) error
type UnimplementedKVServer ¶
type UnimplementedKVServer struct {
}
UnimplementedKVServer must be embedded to have forward compatible implementations.
func (UnimplementedKVServer) Tx ¶
func (UnimplementedKVServer) Tx(KV_TxServer) error
type UnsafeDBServer ¶
type UnsafeDBServer interface {
// contains filtered or unexported methods
}
UnsafeDBServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DBServer will result in compilation errors.
type UnsafeETHBACKENDServer ¶
type UnsafeETHBACKENDServer interface {
// contains filtered or unexported methods
}
UnsafeETHBACKENDServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ETHBACKENDServer will result in compilation errors.
type UnsafeKVServer ¶
type UnsafeKVServer interface {
// contains filtered or unexported methods
}
UnsafeKVServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to KVServer will result in compilation errors.